PCB Environment: PCBFactory Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
PCBFactory Class Reference

## Public Member Functions
const std::string & | getData () const
PCBoard * | create (const std::string &data)
PCBoard * | loadAndCreate (const std::string &filePath)
void | setUnitLength_nm (Nanometers nm)
Nanometers | getUnitLength_nm (Nanometers Default) const
void | setForceDesignRes (bool b)
bool | designResForced () const
void | setFixedTrackParams (bool b)
Real | hasFixedTrackParams () const
void | setNetOverrides (PyObject *over)
const NetOverrides & | getNetOverrides () const
void | setTopologies (PyObject *)
const NetTopology * | getTopology (const std::string &net) const
void | setAutocreateConnections (bool b)
bool | autocreateConnections () const
void | setLockRoutedConnections (bool b)
void | setLoadFanout (bool b)
bool | getLoadFanout () const
void | setLoadTracks (PyObject *)
bool | getLoadTracksForNet (const std::string &name) const
void | setRectifySegmentsDegrees (Real deg)
Real | getRectifySegmentsRadians () const
void | setLoadPolygonsAsBoxes (bool b)
bool | loadPolygonsAsBoxes () const
void | setLayoutAreaMinMargin (float v)
void | setLayoutAreaMaxMargin (float v)
float | getLayoutAreaMinMargin () const
float | getLayoutAreaMaxMargin () const
void | setIgnoreLayoutBounds (bool b)
bool | ignoreLayoutBounds () const
bool | checkPinIntersections () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/Factory.hpp